@@ -5,9 +5,10 @@ from django.db.models import (
     IntegerField, SmallIntegerField, PositiveIntegerField,
     PositiveSmallIntegerField, BooleanField, DecimalField,
     FloatField, FileField, ImageField, IPAddressField,
-    ForeignKey, ManyToManyField, OneToOneField)
+    ForeignKey, ManyToManyField, OneToOneField, NullBooleanField)
 
-from model_mommy.utils import import_if_str
+from .gis import default_gis_mapping
+from .utils import import_if_str
 
 try:
     from django.db.models import BigIntegerField
@@ -50,12 +51,14 @@ except ImportError:
     HStoreField = None
 
 from . import random_gen
+
 default_mapping = {
     ForeignKey: random_gen.gen_related,
     OneToOneField: random_gen.gen_related,
     ManyToManyField: random_gen.gen_m2m,
 
     BooleanField: random_gen.gen_boolean,
+    NullBooleanField: random_gen.gen_null_boolean,
     IntegerField: random_gen.gen_integer,
     BigIntegerField: random_gen.gen_integer,
     SmallIntegerField: random_gen.gen_integer,
@@ -97,6 +100,9 @@ if JSONField:
 if HStoreField:
     default_mapping[HStoreField] = random_gen.gen_hstore
 
+# Add GIS fields
+default_mapping.update(default_gis_mapping)
+
 
 def get_type_mapping():
     mapping = default_mapping.copy()
