@@ -5,16 +5,12 @@ import django
 
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
-if django.VERSION >= (1, 7):
-    from django.apps import apps
-    get_model = apps.get_model
-    from django.contrib.contenttypes.fields import GenericRelation
-else:
-    from django.db.models.loading import get_model, cache
-    from django.contrib.contenttypes.generic import GenericRelation
+from django.apps import apps
+get_model = apps.get_model
+from django.contrib.contenttypes.fields import GenericRelation
 
 from django.db.models.base import ModelBase
-from django.db.models import ForeignKey, ManyToManyField, OneToOneField, Field, AutoField, BooleanField
+from django.db.models import ForeignKey, ManyToManyField, OneToOneField, Field, AutoField, BooleanField, FileField
 if django.VERSION >= (1, 9):
     from django.db.models.fields.related import ReverseManyToOneDescriptor as ForeignRelatedObjectsDescriptor
 else:
@@ -41,14 +37,14 @@ def _valid_quantity(quantity):
     return quantity is not None and (not isinstance(quantity, int) or quantity < 1)
 
 
-def make(model, _quantity=None, make_m2m=False, _save_kwargs=None, **attrs):
+def make(_model, _quantity=None, make_m2m=False, _save_kwargs=None, _create_files=False, **attrs):
     """
     Creates a persisted instance from a given model its associated models.
     It fill the fields with random values or you can specify
     which fields you want to define its values by yourself.
     """
     _save_kwargs = _save_kwargs or {}
-    mommy = Mommy.create(model, make_m2m=make_m2m)
+    mommy = Mommy.create(_model, make_m2m=make_m2m, create_files=_create_files)
     if _valid_quantity(_quantity):
         raise InvalidQuantityException
 
@@ -58,14 +54,14 @@ def make(model, _quantity=None, make_m2m=False, _save_kwargs=None, **attrs):
         return mommy.make(_save_kwargs=_save_kwargs, **attrs)
 
 
-def prepare(model, _quantity=None, _save_related=False, **attrs):
+def prepare(_model, _quantity=None, _save_related=False, **attrs):
     """
     Creates BUT DOESN'T persist an instance from a given model its
     associated models.
     It fill the fields with random values or you can specify
     which fields you want to define its values by yourself.
     """
-    mommy = Mommy.create(model)
+    mommy = Mommy.create(_model)
     if _valid_quantity(_quantity):
         raise InvalidQuantityException
 
@@ -106,8 +102,7 @@ class ModelFinder(object):
                 model = get_model(app_label, model_name)
             else:
                 model = self.get_model_by_name(name)
-        except LookupError:  # Django 1.7.0a1 throws an exception
-            # Lower djangos just fail silently
+        except LookupError:
             model = None
 
         if not model:
@@ -140,10 +135,7 @@ class ModelFinder(object):
         unique_models = {}
         ambiguous_models = []
 
-        if django.VERSION >= (1, 7):
-            all_models = apps.all_models
-        else:
-            all_models = cache.app_models
+        all_models = apps.all_models
 
         for app_model in all_models.values():
             for name, model in app_model.items():
@@ -199,25 +191,26 @@ class Mommy(object):
     finder = ModelFinder()
 
     @classmethod
-    def create(cls, model, make_m2m=False):
+    def create(cls, _model, make_m2m=False, create_files=False):
         """
         Factory which creates the mommy class defined by the MOMMY_CUSTOM_CLASS setting
         """
         mommy_class = _custom_mommy_class() or cls
-        return mommy_class(model, make_m2m)
+        return mommy_class(_model, make_m2m, create_files)
 
-    def __init__(self, model, make_m2m=False):
+    def __init__(self, _model, make_m2m=False, create_files=False):
         self.make_m2m = make_m2m
+        self.create_files = create_files
         self.m2m_dict = {}
         self.iterator_attrs = {}
         self.model_attrs = {}
         self.rel_attrs = {}
         self.rel_fields = []
 
-        if isinstance(model, ModelBase):
-            self.model = model
+        if isinstance(_model, ModelBase):
+            self.model = _model
         else:
-            self.model = self.finder.get_model(model)
+            self.model = self.finder.get_model(_model)
 
         self.init_type_mapping()
 
@@ -243,10 +236,7 @@ class Mommy(object):
         return self.model._meta.fields + self.model._meta.many_to_many
 
     def get_related(self):
-        if django.VERSION[:2] <= (1, 7):
-            return self.model._meta.get_all_related_objects()
-        else:
-            return [r for r in self.model._meta.related_objects if not r.many_to_many]
+        return [r for r in self.model._meta.related_objects if not r.many_to_many]
 
     def _make(self, commit=True, commit_related=True, _save_kwargs=None, **attrs):
         _save_kwargs = _save_kwargs or {}
@@ -262,7 +252,8 @@ class Mommy(object):
                 else:
                     self.m2m_dict[field.name] = self.model_attrs.pop(field.name)
             elif field.name not in self.model_attrs:
-                self.model_attrs[field.name] = self.generate_value(field, commit_related)
+                if not isinstance(field, ForeignKey) or '{0}_id'.format(field.name) not in self.model_attrs:
+                    self.model_attrs[field.name] = self.generate_value(field, commit_related)
             elif callable(self.model_attrs[field.name]):
                 self.model_attrs[field.name] = self.model_attrs[field.name]()
             elif field.name in self.iterator_attrs:
@@ -307,7 +298,7 @@ class Mommy(object):
 
         kwargs = filter_rel_attrs(rel_name, **self.rel_attrs)
         kwargs[related.field.name] = instance
-        kwargs['model'] = related.field.model
+        kwargs['_model'] = related.field.model
 
         make(**kwargs)
 
@@ -326,8 +317,11 @@ class Mommy(object):
         else:
             field.fill_optional = field.name in self.fill_in_optional
 
+        if isinstance(field, FileField) and not self.create_files:
+            return True
+
         # Skip links to parent so parent is not created twice.
-        if isinstance(field, OneToOneField) and field.rel.parent_link:
+        if isinstance(field, OneToOneField) and self._remote_field(field).parent_link:
             return True
 
         if isinstance(field, (AutoField, GenericRelation, OrderWrt)):
@@ -371,6 +365,11 @@ class Mommy(object):
                     }
                     make(through_model, **base_kwargs)
 
+    def _remote_field(self, field):
+        if django.VERSION >= (1, 9):
+            return field.remote_field
+        return field.rel
+
     def generate_value(self, field, commit=True):
         '''
         Calls the generator associated with a field passing all required args.
@@ -389,12 +388,12 @@ class Mommy(object):
             generator = self.attr_mapping[field.name]
         elif getattr(field, 'choices'):
             generator = random_gen.gen_from_choices(field.choices)
-        elif isinstance(field, ForeignKey) and issubclass(field.rel.to, ContentType):
+        elif isinstance(field, ForeignKey) and issubclass(self._remote_field(field).model, ContentType):
             generator = self.type_mapping[ContentType]
-        elif field.__class__ in self.type_mapping:
-            generator = self.type_mapping[field.__class__]
         elif generators.get(field.__class__):
             generator = generators.get(field.__class__)
+        elif field.__class__ in self.type_mapping:
+            generator = self.type_mapping[field.__class__]
         else:
             raise TypeError('%s is not supported by mommy.' % field.__class__)
 
